@@ -1,20 +1,20 @@
-id = "b26b7f4aef02f8d85d7650f3d09bba87b6db1bdc"
-date = "2016-08-11 22:08:55 +0000"
-branch = "glue-1-51-branch"
-tag = "glue-release-1-51-0"
+id = "470f60cf6e3dbb4aaef60e1580b5bee94862eb7c"
+date = "2016-10-24 13:50:25 +0000"
+branch = "glue-1-53-branch"
+tag = "glue-release-1-53"
 if tag == "None":
     tag = None
-author = "Ryan Fisher <ryan.fisher@ligo.org>"
+author = "Kipp Cannon <kipp.cannon@ligo.org>"
 builder = "Ryan Fisher <ryan.fisher@ligo.org>"
-committer = "Ryan Fisher <ryan.fisher@ligo.org>"
+committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
-verbose_msg = """Branch: glue-1-51-branch
-Tag: glue-release-1-51-0
-Id: b26b7f4aef02f8d85d7650f3d09bba87b6db1bdc
+verbose_msg = """Branch: glue-1-53-branch
+Tag: glue-release-1-53
+Id: 470f60cf6e3dbb4aaef60e1580b5bee94862eb7c
 
 Builder: Ryan Fisher <ryan.fisher@ligo.org>
-Build date: 2016-08-11 22:16:21 +0000
+Build date: 2016-10-24 17:06:20 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "b26b7f4aef02f8d85d7650f3d09bba87b6db1bdc":
+    if foreign_id == "470f60cf6e3dbb4aaef60e1580b5bee94862eb7c":
         return
-    msg = "Program id (b26b7f4aef02f8d85d7650f3d09bba87b6db1bdc) does not match given id (%s)." % foreign_id
+    msg = "Program id (470f60cf6e3dbb4aaef60e1580b5bee94862eb7c) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
