@@ -1,4 +1,4 @@
-# Copyright (C) 2006--2015  Kipp Cannon
+# Copyright (C) 2006--2016  Kipp Cannon
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -73,81 +73,20 @@ __date__ = git_version.date
 #
 
 
-# Regular expression to extract the significant part of a column name
-# according to the LIGO LW naming conventions.
-
-# FIXME: the pattern should be
-#
-# r"(?:\A[a-z0-9_]+:|\A)(?P<FullName>(?:[a-z0-9_]+:|\A)(?P<Name>[a-z0-9_]+))\Z"
-#
-# but people are putting upper case letters in names!!!!!  Someone is going
-# to get the beats.  There is a reason for requiring names to be all lower
-# case:  SQL table and column names are case insensitive, therefore (i)
-# when converting a document to SQL the columns "Rho" and "rho" would
-# become indistinguishable and so it would be impossible to convert a
-# document with columns having names like this into an SQL database;  and
-# (ii) even if that degeneracy is not encountered the case cannot be
-# preserved and so when converting back to XML the correct capitalization
-# is lost.  Requiring names to be all lower-case creates the same
-# degeneracies in XML representations that exist in SQL representations
-# ensuring compatibility and defines the correct case to restore the names
-# to when converting to XML.  Other rules can be imagined that would work
-# as well, this is the one that got chosen.
-
-
-ColumnPattern = re.compile(r"(?:\A\w+:|\A)(?P<FullName>(?:(?P<Table>\w+):|\A)(?P<Name>\w+))\Z")
-
-
 def StripColumnName(name):
-	"""
-	Return the significant portion of a column name according to LIGO
-	LW naming conventions.
-
-	Example:
-
-	>>> StripColumnName("process_params_group:process_params:program")
-	'program'
-	>>> StripColumnName("process_params:program")
-	'program'
-	>>> StripColumnName("program")
-	'program'
-	"""
-	if name.lower() != name:
-		warnings.warn("column name \"%s\" is not lower case" % name)
-	try:
-		return ColumnPattern.search(name).group("Name")
-	except AttributeError:
-		return name
-
+	warnings.warn("use Column.ColumnName() instead", DeprecationWarning)
+	return Column.ColumnName(name)
 
 def CompareColumnNames(name1, name2):
-	"""
-	Convenience function to compare two column names according to LIGO
-	LW naming conventions:  StripColumnName() is applied to both names
-	and the results compared.
-
-	Example:
-
-	>>> # compare as equal
-	>>> CompareColumnNames("process_params:program", "process:program")
-	0
-	>>> # not equal
-	>>> CompareColumnNames("program", "start_time")
-	-1
-
-	Note that "process_params:program", "process:program" compare as
-	equal because both columns are named "program" although they are
-	from different tables.
-	"""
-	return cmp(StripColumnName(name1), StripColumnName(name2))
+	warnings.warn("use cmp(Column.ColumnName(), Column.ColumnName()) instead", DeprecationWarning)
+	return cmp(Column.ColumnName(name1), Column.ColumnName(name2))
 
 
 def getColumnsByName(elem, name):
 	"""
-	Return a list of Column elements named name under elem.  The name
-	comparison is done with CompareColumnNames().
+	Return a list of Column elements named name under elem.
 	"""
-	name = StripColumnName(name)
+	name = Column.ColumnName(name)
 	return elem.getElements(lambda e: (e.tagName == ligolw.Column.tagName) and (e.Name == name))
 
 
@@ -160,59 +99,20 @@ def getColumnsByName(elem, name):
 #
 
 
-# Regular expression used to extract the signifcant portion of a table or
-# stream name, according to LIGO LW naming conventions.
-
-
-TablePattern = re.compile(r"(?:\A[a-z0-9_]+:|\A)(?P<Name>[a-z0-9_]+):table\Z")
-
-
 def StripTableName(name):
-	"""
-	Return the significant portion of a table name according to LIGO LW
-	naming conventions.
-
-	Example:
-
-	>>> StripTableName("sngl_burst_group:sngl_burst:table")
-	'sngl_burst'
-	>>> StripTableName("sngl_burst:table")
-	'sngl_burst'
-	>>> StripTableName("sngl_burst")
-	'sngl_burst'
-	"""
-	if name.lower() != name:
-		warnings.warn("table name \"%s\" is not lower case" % name)
-	try:
-		return TablePattern.search(name).group("Name")
-	except AttributeError:
-		return name
-
+	warnings.warn("use Table.TableName() instead", DeprecationWarning)
+	return Table.TableName(name)
 
 def CompareTableNames(name1, name2):
-	"""
-	Convenience function to compare two table names according to LIGO
-	LW naming conventions.  StripTableName() is applied to both names
-	and the results compared.
-
-	Example:
-
-	>>> # compare as equal
-	>>> CompareTableNames("sngl_inspiral:table", "sngl_inspiral")
-	0
-	>>> # not equal
-	>>> CompareTableNames("sngl_burst_group:sngl_burst:table", "sngl_inspiral")
-	-1
-	"""
-	return cmp(StripTableName(name1), StripTableName(name2))
+	warnings.warn("use cmp(Table.TableName(), Table.TableName()) instead", DeprecationWarning)
+	return cmp(Table.TableName(name1), Table.TableName(name2))
 
 
 def getTablesByName(elem, name):
 	"""
-	Return a list of Table elements named name under elem.  The name
-	comparison is done using CompareTableNames().
+	Return a list of Table elements named name under elem.
 	"""
-	name = StripTableName(name)
+	name = Table.TableName(name)
 	return elem.getElements(lambda e: (e.tagName == ligolw.Table.tagName) and (e.Name == name))
 
 
@@ -225,20 +125,10 @@ def getTablesByName(elem, name):
 #
 
 
-def new_from_template(template):
-	"""
-	Deprecated legacy wrapper of .copy() method of Table instances.
-	"""
-	import warnings
-	warnings.warn("glue.ligolw.table.new_from_template() is deprecated.  Use .copy() method of Table instances instead.", DeprecationWarning)
-	return template.copy()
-
-
 def get_table(xmldoc, name):
 	"""
-	Scan xmldoc for a Table element named name.  The comparison is done
-	using CompareTableNames().  Raises ValueError if not exactly 1 such
-	table is found.
+	Scan xmldoc for a Table element named name.  Raises ValueError if
+	not exactly 1 such table is found.
 
 	NOTE:  if a Table sub-class has its .tableName attribute set, then
 	its .get_table() class method can be used instead.  This is true
@@ -264,7 +154,7 @@ def get_table(xmldoc, name):
 	"""
 	tables = getTablesByName(xmldoc, name)
 	if len(tables) != 1:
-		raise ValueError("document must contain exactly one %s table" % StripTableName(name))
+		raise ValueError("document must contain exactly one %s table" % Table.TableName(name))
 	return tables[0]
 
 
@@ -373,6 +263,8 @@ class Column(ligolw.Column):
 	</Table>
 	>>> col.index(10)
 	1
+	>>> 12 in col
+	True
 	>>> col[0] = 9.
 	>>> col[1] = 9.
 	>>> col[2] = 9.
@@ -389,12 +281,11 @@ class Column(ligolw.Column):
 	3
 
 	NOTE:  the .Name attribute returns the stripped "Name" attribute of
-	the element, e.g. as would be obtained with StripColumnName(), but
-	when assigning to the .Name attribute the value provided is stored
-	without modification, i.e. there is no attempt to reattach the
-	table's name to the string.  The calling code is responsible for
-	doing the correct manipulations.  Therefore, the assignment
-	operation below
+	the element, e.g. with the table suffix removed, but when assigning
+	to the .Name attribute the value provided is stored without
+	modification, i.e. there is no attempt to reattach the table's name
+	to the string.  The calling code is responsible for doing the
+	correct manipulations.  Therefore, the assignment operation below
 
 	>>> col.Name, col.getAttribute("Name")
 	(u'snr', u'test:snr')
@@ -409,7 +300,30 @@ class Column(ligolw.Column):
 	the Column object is not part of an XML tree and does not have a
 	parent node.
 	"""
-	Name = ligolw.attributeproxy(u"Name", dec = StripColumnName)
+	# FIXME: the pattern should be
+	#
+	# r"(?:\A[a-z0-9_]+:|\A)(?P<FullName>(?:[a-z0-9_]+:|\A)(?P<Name>[a-z0-9_]+))\Z"
+	#
+	# but people are putting upper case letters in names!!!!!  Someone
+	# is going to get the beats.  There is a reason for requiring names
+	# to be all lower case:  SQL table and column names are case
+	# insensitive, therefore (i) when converting a document to SQL the
+	# columns "Rho" and "rho" would become indistinguishable and so it
+	# would be impossible to convert a document with columns having
+	# names like this into an SQL database;  and (ii) even if that
+	# degeneracy is not encountered the case cannot be preserved and so
+	# when converting back to XML the correct capitalization is lost.
+	# Requiring names to be all lower-case creates the same
+	# degeneracies in XML representations that exist in SQL
+	# representations ensuring compatibility and defines the correct
+	# case to restore the names to when converting to XML.  Other rules
+	# can be imagined that would work as well, this is the one that got
+	# chosen.
+	class ColumnName(ligolw.LLWNameAttr):
+		dec_pattern = re.compile(r"(?:\A\w+:|\A)(?P<FullName>(?:(?P<Table>\w+):|\A)(?P<Name>\w+))\Z")
+		enc_pattern = u"%s"
+
+	Name = ligolw.attributeproxy(u"Name", enc = ColumnName.enc, dec = ColumnName)
 
 	def __len__(self):
 		"""
@@ -422,7 +336,7 @@ class Column(ligolw.Column):
 		Retrieve the value in this column in row i.
 		"""
 		if isinstance(i, slice):
-			return map(lambda r: getattr(r, self.Name), self.parentNode[i])
+			return [getattr(r, self.Name) for r in self.parentNode[i]]
 		else:
 			return getattr(self.parentNode[i], self.Name)
 
@@ -460,15 +374,15 @@ class Column(ligolw.Column):
 		"""
 		Return the number of rows with this column equal to value.
 		"""
-		return sum(getattr(row, self.Name) == value for row in self.parentNode)
+		return sum(x == value for x in self)
 
 	def index(self, value):
 		"""
 		Return the smallest index of the row(s) with this column
 		equal to value.
 		"""
-		for i in xrange(len(self.parentNode)):
-			if getattr(self.parentNode[i], self.Name) == value:
+		for i, x in enumerate(self):
+			if x == value:
 				return i
 		raise ValueError(value)
 
@@ -477,10 +391,7 @@ class Column(ligolw.Column):
 		Returns True or False if there is or is not, respectively,
 		a row containing val in this column.
 		"""
-		for i in xrange(len(self.parentNode)):
-			if getattr(self.parentNode[i], self.Name) == value:
-				return True
-		return False
+		return value in iter(self)
 
 	def asarray(self):
 		"""
@@ -585,11 +496,6 @@ class TableStream(ligolw.Stream):
 	that it appends into the list-like parent element, and knows how to
 	turn the parent's rows back into a character stream.
 	"""
-	def __init__(self, *args):
-		super(TableStream, self).__init__(*args)
-		self._tokenizer = tokenizer.Tokenizer(self.Delimiter)
-		self._rowbuilder = None
-
 	def config(self, parentNode):
 		# some initialization that requires access to the
 		# parentNode, and so cannot be done inside the __init__()
@@ -599,6 +505,7 @@ class TableStream(ligolw.Stream):
 			# FIXME:  convert loadcolumns attributes to sets to
 			# avoid the conversion.
 			loadcolumns &= set(parentNode.loadcolumns)
+		self._tokenizer = tokenizer.Tokenizer(self.Delimiter)
 		self._tokenizer.set_types([(pytype if colname in loadcolumns else None) for pytype, colname in zip(parentNode.columnpytypes, parentNode.columnnames)])
 		columnnames = [name for name in parentNode.columnnames if name in loadcolumns]
 		# FIXME:  convert interncolumns attributes to sets to
@@ -614,22 +521,19 @@ class TableStream(ligolw.Stream):
 		for row in self._rowbuilder.append(self._tokenizer.append(content)):
 			appendfunc(row)
 
-	def unlink(self):
-		"""
-		Break internal references within the document tree rooted
-		on this element to promote garbage collection.
-		"""
-		self._tokenizer = None
-		self._rowbuilder = None
-		super(TableStream, self).unlink()
-
 	def endElement(self):
 		# stream tokenizer uses delimiter to identify end of each
 		# token, so add a final delimiter to induce the last token
 		# to get parsed but only if there's something other than
-		# whitespace left in the tokenizer's buffer.
+		# whitespace left in the tokenizer's buffer.  the writing
+		# code will have put a final delimiter into the stream if
+		# the final token was pure whitespace in order to
+		# unambiguously indicate that token's presence
 		if not self._tokenizer.data.isspace():
 			self.appendData(self.Delimiter)
+		# now we're done with these
+		del self._tokenizer
+		del self._rowbuilder
 		# call parent's _end_of_rows() hook.
 		self.parentNode._end_of_rows()
 
@@ -644,7 +548,7 @@ class TableStream(ligolw.Stream):
 		rowdumper = tokenizer.RowDumper(self.parentNode.columnnames, [ligolwtypes.FormatFunc[coltype] for coltype in self.parentNode.columntypes], self.Delimiter)
 		rowdumper.dump(self.parentNode)
 		try:
-			line = rowdumper.next()
+			line = next(rowdumper)
 		except StopIteration:
 			# table is empty
 			pass
@@ -695,6 +599,12 @@ class Table(ligolw.Table, list):
 	"""
 	High-level Table element that knows about its columns and rows.
 	"""
+	class TableName(ligolw.LLWNameAttr):
+		dec_pattern = re.compile(r"(?:\A[a-z0-9_]+:|\A)(?P<Name>[a-z0-9_]+):table\Z")
+		enc_pattern = u"%s:table"
+
+	Name = ligolw.attributeproxy(u"Name", enc = TableName.enc, dec = TableName)
+
 	validcolumns = None
 	loadcolumns = None
 	interncolumns = None
@@ -712,8 +622,6 @@ class Table(ligolw.Table, list):
 		self.columntypes = []
 		self.columnpytypes = []
 
-	Name = ligolw.attributeproxy(u"Name", enc = (lambda name: u"%s:table" % name), dec = StripTableName)
-
 
 	#
 	# Table retrieval
@@ -755,9 +663,9 @@ class Table(ligolw.Table, list):
 		attribute on the Table object.
 		"""
 		new = copy.copy(self)
-		new.childNodes = map(copy.copy, self.childNodes)
-		for child in new.childNodes:
-			child.parentNode = new
+		new.childNodes = []	# got reference to original list
+		for elem in self.childNodes:
+			new.appendChild(copy.copy(elem))
 		del new[:]
 		new._end_of_columns()
 		new._end_of_rows()
@@ -768,9 +676,8 @@ class Table(ligolw.Table, list):
 	def CheckElement(cls, elem):
 		"""
 		Return True if element is a Table element whose Name
-		attribute matches the .tableName attribute of this class
-		according to CompareTableNames();  return False otherwise.
-		See also .CheckProperties().
+		attribute matches the .tableName attribute of this class ;
+		return False otherwise.  See also .CheckProperties().
 		"""
 		return cls.CheckProperties(elem.tagName, elem.attributes)
 
@@ -781,11 +688,10 @@ class Table(ligolw.Table, list):
 		Return True if tagname and attrs are the XML tag name and
 		element attributes, respectively, of a Table element whose
 		Name attribute matches the .tableName attribute of this
-		class according to CompareTableNames();  return False
-		otherwise.  The Table parent class does not provide a
-		.tableName attribute, but sub-classes, especially those in
-		lsctables.py, do provide a value for that attribute.  See
-		also .CheckElement()
+		class;  return False otherwise.  The Table parent class
+		does not provide a .tableName attribute, but sub-classes,
+		especially those in lsctables.py, do provide a value for
+		that attribute.  See also .CheckElement()
 
 		Example:
 
@@ -793,7 +699,8 @@ class Table(ligolw.Table, list):
 		>>> lsctables.ProcessTable.CheckProperties(u"Table", {u"Name": u"process:table"})
 		True
 		"""
-		return tagname == cls.tagName and not CompareTableNames(attrs[u"Name"], cls.tableName)
+		# FIXME:  are these tests correct?
+		return tagname == cls.tagName and not cmp(cls.TableName(attrs[u"Name"]), cls.TableName(cls.tableName))
 
 
 	#
@@ -803,7 +710,7 @@ class Table(ligolw.Table, list):
 	def getColumnByName(self, name):
 		"""
 		Retrieve and return the Column child element named name.
-		The comparison is done using CompareColumnNames().  Raises
+		The comparison is done using the stripped names.  Raises
 		KeyError if this table has no column by that name.
 
 		Example:
@@ -840,9 +747,9 @@ class Table(ligolw.Table, list):
 		>>> process_table = lsctables.New(lsctables.ProcessTable, [])
 		>>> col = process_table.appendColumn("program")
 		>>> col.getAttribute("Name")
-		'process:program'
+		u'process:program'
 		>>> col.Name
-		'program'
+		u'program'
 		"""
 		try:
 			self.getColumnByName(name)
@@ -850,7 +757,7 @@ class Table(ligolw.Table, list):
 			raise ValueError("duplicate Column '%s'" % name)
 		except KeyError:
 			pass
-		column = Column(AttributesImpl({u"Name": "%s:%s" % (StripTableName(self.tableName), name), u"Type": self.validcolumns[name]}))
+		column = Column(AttributesImpl({u"Name": "%s:%s" % (self.TableName(self.tableName), name), u"Type": self.validcolumns[name]}))
 		streams = self.getElementsByTagName(ligolw.Stream.tagName)
 		if streams:
 			self.insertBefore(column, streams[0])
