@@ -1,4 +1,4 @@
-# Copyright (C) 2010--2013  Kipp Cannon
+# Copyright (C) 2010--2013,2015,2016  Kipp Cannon
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -293,9 +293,7 @@ def component_offsetvectors(offsetvectors, n):
 	"L1": 20} can be constructed from the coincs for the vectors {"H1":
 	0, "H2": 10} and {"H2": 0, "L1": 10}, that is only the relative
 	offsets are significant in determining if two events are
-	coincident, not the absolute offsets.  This assumption is not true
-	for the standard inspiral pipeline, where the absolute offsets are
-	significant due to the periodic wrapping of triggers around rings.
+	coincident, not the absolute offsets.
 	"""
 	#
 	# collect unique instrument set / deltas combinations
