@@ -281,7 +281,11 @@ static PyObject *__abs__(PyObject *self)
 	Py_ssize_t i;
 	PyObject *abs;
 
+#if PY_MAJOR_VERSION < 3
 	abs = PyInt_FromLong(0);
+#else
+	abs = PyLong_FromLong(0);
+#endif
 	if(!abs)
 		return NULL;
 
@@ -376,7 +380,11 @@ static PyObject *find(PyObject *self, PyObject *item)
 		} else if(result > 0) {
 			Py_DECREF(item);
 			/* match found */
+#if PY_MAJOR_VERSION < 3
 			return PyInt_FromLong(i);
+#else
+			return PyLong_FromLong(i);
+#endif
 		}
 	}
 	Py_DECREF(item);
@@ -1216,7 +1224,11 @@ static PyObject *protract(PyObject *self, PyObject *delta)
 	if(n < 0)
 		return NULL;
 
+#if PY_MAJOR_VERSION < 3
 	protract = PyString_FromString("protract");
+#else
+	protract = PyUnicode_FromString("protract");
+#endif
 	if(!protract)
 		return NULL;
 
@@ -1255,7 +1267,11 @@ static PyObject *contract(PyObject *self, PyObject *delta)
 	if(n < 0)
 		return NULL;
 
+#if PY_MAJOR_VERSION < 3
 	contract = PyString_FromString("contract");
+#else
+	contract = PyUnicode_FromString("contract");
+#endif
 	if(!contract)
 		return NULL;
 
@@ -1294,7 +1310,11 @@ static PyObject *shift(PyObject *self, PyObject *delta)
 	if(n < 0)
 		return NULL;
 
+#if PY_MAJOR_VERSION < 3
 	shift = PyString_FromString("shift");
+#else
+	shift = PyUnicode_FromString("shift");
+#endif
 	if(!shift)
 		return NULL;
 
@@ -1400,7 +1420,11 @@ PyTypeObject segments_SegmentList_Type = {
 "[segment(-10, -5), segment(5, 10), segment(20, 30)]\n" \
 ">>> print ~x\n" \
 "[segment(-infinity, -10), segment(-5, 5), segment(10, 20), segment(30, infinity)]",
-	.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES | Py_TPFLAGS_BASETYPE,
+	.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE
+#if PY_MAJOR_VERSION < 3
+	| Py_TPFLAGS_CHECKTYPES
+#endif
+	,
 	.tp_methods = methods,
 	.tp_name = MODULE_NAME ".segmentlist",
 };
