@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 
 import doctest
+import sys
 from glue.ligolw import array
 
 if __name__ == '__main__':
-	doctest.testmod(array)
+	failures = doctest.testmod(array)[0]
+	sys.exit(bool(failures))
